@@ -19,10 +19,15 @@ def add_certificates():
         f.writelines(certs)
     # Add Vestas certificates.
     for item in os.listdir(certificate_dir):
+        src = os.path.join(certificate_dir, item)
+        if os.path.isdir(src):
+            continue
+        if src[-4:] != ".crt":
+            continue
         certs.append("\n")
         certs.append("# Source: " + item)
         certs.append("\n")
-        with open(os.path.join(certificate_dir, item), 'r') as f:
+        with open(src, 'r') as f:
             cert = f.readlines()
             certs.extend(cert)
     # Write the result.
